/*
 * NASPRO - The NASPRO Architecture for Sound Processing
 * Core library
 *
 * Copyright (C) 2007-2011 NASPRO core development team
 *
 * See the COPYING file for license conditions.
 */

#ifndef _NACORE_INTERNAL_H
#define _NACORE_INTERNAL_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>

#include <math.h>

#include <NASPRO/core/lib.h>

#include "localepvt.h"

#endif
